@@ -2,21 +2,22 @@ package CloudFlare::Client::Exception::Connection;
 # ABSTRACT: CloudFlare API Connection Exception
 
 use Modern::Perl '2012';
-use autodie ':all';
+use autodie      ':all';
+no  indirect     'fatal';
+use namespace::autoclean;
 
 use Readonly;
-use namespace::autoclean;
-use Moose;
-use MooseX::StrictConstructor;
-use MooseX::Types::Moose qw( Str );
+use Moose; use MooseX::StrictConstructor;
+use Types::Standard 'Str';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 extends 'Throwable::Error';
 
 has status => (
     is       => 'ro',
-    isa      => Str);
+    isa      => Str,
+    required => 1);
 
 __PACKAGE__->meta->make_immutable;
 1; # End of CloudFlare::Client::Exception::Connection
@@ -33,7 +34,7 @@ CloudFlare::Client::Exception::Connection - CloudFlare API Connection Exception
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
