@@ -2,15 +2,15 @@ package CloudFlare::Client::Exception::Upstream;
 # ABSTRACT: Upstream CloudFlare API Exception
 
 use Modern::Perl '2012';
-use autodie ':all';
+use autodie      ':all';
+no  indirect     'fatal';
+use namespace::autoclean;
 
 use Readonly;
-use namespace::autoclean;
-use Moose;
-use MooseX::StrictConstructor;
-use CloudFlare::Client::Types ':all';
+use Moo; use MooX::StrictConstructor;
+use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 extends 'Throwable::Error';
 
@@ -33,7 +33,7 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
