@@ -2,17 +2,21 @@ package CloudFlare::Client::Types;
 # ABSTRACT: Types for Cloudflare::Client
 
 use Modern::Perl '2012';
-use autodie ':all';
-
+use autodie      ':all';
+no  indirect     'fatal';
 use namespace::autoclean;
-use MooseX::Types -declare => [ qw( CFCode ErrorCode ) ];
-use MooseX::Types::Moose qw( Undef );
+
+use Type::Library -base, -declare => qw( CFCode ErrorCode);
+# Theres a bug about using undef as a hashref before this version
+use Type::Utils 0.039_12 -all;
+use Types::Standard qw( Enum Maybe);
 use Readonly;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
-enum CFCode, [ qw( E_UNAUTH E_INVLDINPUT E_MAXAPI ) ];
-union ErrorCode, [ Undef, CFCode ];
+class_type 'LWP::UserAgent';
+declare CFCode, as Enum[qw( E_UNAUTH E_INVLDINPUT E_MAXAPI)];
+declare ErrorCode, as Maybe[CFCode];
 
 1; # End of CloudFlare::Client::Types
 
@@ -28,7 +32,7 @@ CloudFlare::Client::Types - Types for Cloudflare::Client
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
